from typing import Any, Dict, Type, TypeVar

import attr

from ..models.data_source_details_request import DataSourceDetailsRequest

T = TypeVar("T", bound="UpdateDataSourceDetailsRequest")


@attr.s(auto_attribs=True)
class UpdateDataSourceDetailsRequest:
    """
    Attributes:
        details (DataSourceDetailsRequest):
    """

    details: DataSourceDetailsRequest

    def to_dict(self) -> Dict[str, Any]:
        details = self.details.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "details": details,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        details = DataSourceDetailsRequest.from_dict(d.pop("details"))

        update_data_source_details_request = cls(
            details=details,
        )

        return update_data_source_details_request



import datetime
from typing import Any, Dict, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.data_import_task_config import DataImportTaskConfig
from ..types import UNSET, Unset

T = TypeVar("T", bound="AutoDetectTaskConfig")


@attr.s(auto_attribs=True)
class AutoDetectTaskConfig:
    """
    Attributes:
        date_time_header (Union[Unset, None, str]):
        value_header (Union[Unset, None, str]):
        date_time_raw (Union[Unset, None, str]):
        date_time_parsed (Union[Unset, None, datetime.datetime]):
        value_raw (Union[Unset, None, str]):
        value_parsed (Union[Unset, None, float]):
        import_task_config (Union[Unset, None, DataImportTaskConfig]):
    """

    date_time_header: Union[Unset, None, str] = UNSET
    value_header: Union[Unset, None, str] = UNSET
    date_time_raw: Union[Unset, None, str] = UNSET
    date_time_parsed: Union[Unset, None, datetime.datetime] = UNSET
    value_raw: Union[Unset, None, str] = UNSET
    value_parsed: Union[Unset, None, float] = UNSET
    import_task_config: Union[Unset, None, DataImportTaskConfig] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        date_time_header = self.date_time_header
        value_header = self.value_header
        date_time_raw = self.date_time_raw
        date_time_parsed: Union[Unset, None, str] = UNSET
        if not isinstance(self.date_time_parsed, Unset):
            date_time_parsed = self.date_time_parsed.isoformat() if self.date_time_parsed else None

        value_raw = self.value_raw
        value_parsed = self.value_parsed
        import_task_config: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.import_task_config, Unset):
            import_task_config = self.import_task_config.to_dict() if self.import_task_config else None

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if date_time_header is not UNSET:
            field_dict["dateTimeHeader"] = date_time_header
        if value_header is not UNSET:
            field_dict["valueHeader"] = value_header
        if date_time_raw is not UNSET:
            field_dict["dateTimeRaw"] = date_time_raw
        if date_time_parsed is not UNSET:
            field_dict["dateTimeParsed"] = date_time_parsed
        if value_raw is not UNSET:
            field_dict["valueRaw"] = value_raw
        if value_parsed is not UNSET:
            field_dict["valueParsed"] = value_parsed
        if import_task_config is not UNSET:
            field_dict["importTaskConfig"] = import_task_config

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        date_time_header = d.pop("dateTimeHeader", UNSET)

        value_header = d.pop("valueHeader", UNSET)

        date_time_raw = d.pop("dateTimeRaw", UNSET)

        _date_time_parsed = d.pop("dateTimeParsed", UNSET)
        date_time_parsed: Union[Unset, None, datetime.datetime]
        if _date_time_parsed is None:
            date_time_parsed = None
        elif isinstance(_date_time_parsed, Unset):
            date_time_parsed = UNSET
        else:
            date_time_parsed = isoparse(_date_time_parsed)

        value_raw = d.pop("valueRaw", UNSET)

        value_parsed = d.pop("valueParsed", UNSET)

        _import_task_config = d.pop("importTaskConfig", UNSET)
        import_task_config: Union[Unset, None, DataImportTaskConfig]
        if _import_task_config is None:
            import_task_config = None
        elif isinstance(_import_task_config, Unset):
            import_task_config = UNSET
        else:
            import_task_config = DataImportTaskConfig.from_dict(_import_task_config)

        auto_detect_task_config = cls(
            date_time_header=date_time_header,
            value_header=value_header,
            date_time_raw=date_time_raw,
            date_time_parsed=date_time_parsed,
            value_raw=value_raw,
            value_parsed=value_parsed,
            import_task_config=import_task_config,
        )

        return auto_detect_task_config



import uuid
from typing import Any, List, Optional, Type, TypeVar, Union

from structlog import get_logger

from data_source_client import AuthenticatedClient
from data_source_client.api.data_source import (
    data_source_create_data_source,
    data_source_get,
    data_source_update_auto_detect_task_configs,
)
from data_source_client.models.auto_detect_task_config import AutoDetectTaskConfig
from data_source_client.models.create_data_source_request import CreateDataSourceRequest
from data_source_client.models.data_import_description_config import DataImportDescriptionConfig
from data_source_client.models.data_source_details_dto import DataSourceDetailsDTO
from data_source_client.models.en_data_source_state import EnDataSourceState
from data_source_client.models.problem_details import ProblemDetails
from data_source_client.models.update_auto_detect_task_configs_request import UpdateAutoDetectTaskConfigsRequest
from data_source_client.types import UNSET, Unset

from .gnista_connetion import GnistaConnection

log = get_logger()

# pylint: disable=C0103
T = TypeVar("T", bound="GnistaDataSource")


class GnistaDataSource:

    data_source_id: uuid.UUID
    data_import_description: Union[Unset, None, DataImportDescriptionConfig] = UNSET
    auto_detect_task_configs: Union[Unset, None, List[AutoDetectTaskConfig]] = UNSET
    details: Union[Unset, None, DataSourceDetailsDTO] = UNSET
    created_data_points: Union[Unset, None, List[str]] = UNSET
    state: Union[Unset, EnDataSourceState] = UNSET

    @classmethod
    def create_new(
        cls: Type[T],
        connection: GnistaConnection,
        request: CreateDataSourceRequest,
    ) -> Union[T, None]:
        token = connection.get_access_token()
        client = AuthenticatedClient(
            base_url=connection.datasource_base_url, token=token, verify_ssl=connection.verify_ssl
        )

        new_id = uuid.uuid4()
        response = data_source_create_data_source.sync(
            workspace_id=connection.workspace_id, data_source_id=str(new_id), client=client, json_body=request
        )

        if isinstance(response, ProblemDetails):
            log.error(response)
            return None

        data_source = cls(connection=connection, data_source_id=new_id)
        return data_source

    def __init__(self, connection: GnistaConnection, data_source_id: uuid.UUID):
        self.connection = connection
        self.data_source_id = data_source_id
        self._load_details()

    def __str__(self):
        return "GnistaDataSource " + self.data_source_id

    def _load_details(self):
        token = self.connection.get_access_token()
        client = AuthenticatedClient(
            base_url=self.connection.datasource_base_url, token=token, verify_ssl=self.connection.verify_ssl
        )

        data_source = data_source_get.sync(
            client=client,
            data_source_id=str(self.data_source_id),
            workspace_id=self.connection.workspace_id,
        )

        if data_source is None:
            raise Exception("Cannot load Datasource")

        self.data_import_description = data_source.data_import_description
        self.auto_detect_task_configs = data_source.auto_detect_task_configs
        self.details = data_source.details
        self.created_data_points = data_source.created_data_points
        self.state = data_source.state

    def update_auto_detect_task_configs(
        self, request: UpdateAutoDetectTaskConfigsRequest
    ) -> Optional[Union[Any, ProblemDetails]]:
        token = self.connection.get_access_token()
        client = AuthenticatedClient(
            base_url=self.connection.datasource_base_url, token=token, verify_ssl=self.connection.verify_ssl
        )

        response = data_source_update_auto_detect_task_configs.sync(
            client=client,
            data_source_id=str(self.data_source_id),
            workspace_id=self.connection.workspace_id,
            json_body=request,
        )

        if isinstance(response, ProblemDetails):
            log.error(response)

        return response



import uuid
from typing import Generator, List

from structlog import get_logger

from data_source_client import AuthenticatedClient
from data_source_client.api.data_source import data_source_get_all
from data_source_client.models import ProblemDetails
from data_source_client.models.data_source_response import DataSourceResponse

from .gnista_connetion import GnistaConnection
from .gnista_data_source import GnistaDataSource

log = get_logger()


class GnistaDataSources:
    def __init__(self, connection: GnistaConnection, verify_ssl=True):
        self.connection = connection
        self.verify_ssl = verify_ssl

    def get_data_source_list(self) -> Generator[GnistaDataSource, None, None]:
        token = self.connection.get_access_token()
        client = AuthenticatedClient(
            base_url=self.connection.datasource_base_url, token=token, verify_ssl=self.connection.verify_ssl
        )

        data_source_list = data_source_get_all.sync(workspace_id=self.connection.workspace_id, client=client)
        if isinstance(data_source_list, ProblemDetails):
            problems: ProblemDetails = data_source_list
            raise Exception(problems)

        if isinstance(data_source_list, list):
            list_of_data_sources: List[DataSourceResponse] = data_source_list

        for data_source in list_of_data_sources:
            gnista_data_source = GnistaDataSource(
                connection=self.connection, data_source_id=uuid.UUID(data_source.data_source_id)
            )
            yield gnista_data_source



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.auto_detect_task_config import AutoDetectTaskConfig
from ..types import UNSET, Unset

T = TypeVar("T", bound="UpdateAutoDetectTaskConfigsRequest")


@attr.s(auto_attribs=True)
class UpdateAutoDetectTaskConfigsRequest:
    """
    Attributes:
        auto_detect_task_configs (Union[Unset, None, List[AutoDetectTaskConfig]]):
    """

    auto_detect_task_configs: Union[Unset, None, List[AutoDetectTaskConfig]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        auto_detect_task_configs: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.auto_detect_task_configs, Unset):
            if self.auto_detect_task_configs is None:
                auto_detect_task_configs = None
            else:
                auto_detect_task_configs = []
                for auto_detect_task_configs_item_data in self.auto_detect_task_configs:
                    auto_detect_task_configs_item = auto_detect_task_configs_item_data.to_dict()

                    auto_detect_task_configs.append(auto_detect_task_configs_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if auto_detect_task_configs is not UNSET:
            field_dict["autoDetectTaskConfigs"] = auto_detect_task_configs

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        auto_detect_task_configs = []
        _auto_detect_task_configs = d.pop("autoDetectTaskConfigs", UNSET)
        for auto_detect_task_configs_item_data in _auto_detect_task_configs or []:
            auto_detect_task_configs_item = AutoDetectTaskConfig.from_dict(auto_detect_task_configs_item_data)

            auto_detect_task_configs.append(auto_detect_task_configs_item)

        update_auto_detect_task_configs_request = cls(
            auto_detect_task_configs=auto_detect_task_configs,
        )

        return update_auto_detect_task_configs_request



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UpdateStateRequest")


@attr.s(auto_attribs=True)
class UpdateStateRequest:
    """
    Attributes:
        broken (Union[Unset, bool]):
    """

    broken: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        broken = self.broken

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if broken is not UNSET:
            field_dict["broken"] = broken

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        broken = d.pop("broken", UNSET)

        update_state_request = cls(
            broken=broken,
        )

        return update_state_request



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.data_import_task_config import DataImportTaskConfig
from ..types import UNSET, Unset

T = TypeVar("T", bound="DataImportRequest")


@attr.s(auto_attribs=True)
class DataImportRequest:
    """
    Attributes:
        data_source_id (str):
        task_config (Union[Unset, None, DataImportTaskConfig]):
    """

    data_source_id: str
    task_config: Union[Unset, None, DataImportTaskConfig] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        data_source_id = self.data_source_id
        task_config: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.task_config, Unset):
            task_config = self.task_config.to_dict() if self.task_config else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "dataSourceId": data_source_id,
            }
        )
        if task_config is not UNSET:
            field_dict["taskConfig"] = task_config

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        data_source_id = d.pop("dataSourceId")

        _task_config = d.pop("taskConfig", UNSET)
        task_config: Union[Unset, None, DataImportTaskConfig]
        if _task_config is None:
            task_config = None
        elif isinstance(_task_config, Unset):
            task_config = UNSET
        else:
            task_config = DataImportTaskConfig.from_dict(_task_config)

        data_import_request = cls(
            data_source_id=data_source_id,
            task_config=task_config,
        )

        return data_import_request



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.auto_detect_task_config import AutoDetectTaskConfig
from ..models.data_import_description_config import DataImportDescriptionConfig
from ..models.data_source_details_dto import DataSourceDetailsDTO
from ..models.en_data_source_state import EnDataSourceState
from ..types import UNSET, Unset

T = TypeVar("T", bound="DataSourceResponse")


@attr.s(auto_attribs=True)
class DataSourceResponse:
    """
    Attributes:
        data_source_id (str):
        data_import_description (Union[Unset, None, DataImportDescriptionConfig]):
        auto_detect_task_configs (Union[Unset, None, List[AutoDetectTaskConfig]]):
        details (Union[Unset, None, DataSourceDetailsDTO]):
        created_data_points (Union[Unset, None, List[str]]):
        state (Union[Unset, EnDataSourceState]):
    """

    data_source_id: str
    data_import_description: Union[Unset, None, DataImportDescriptionConfig] = UNSET
    auto_detect_task_configs: Union[Unset, None, List[AutoDetectTaskConfig]] = UNSET
    details: Union[Unset, None, DataSourceDetailsDTO] = UNSET
    created_data_points: Union[Unset, None, List[str]] = UNSET
    state: Union[Unset, EnDataSourceState] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        data_source_id = self.data_source_id
        data_import_description: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.data_import_description, Unset):
            data_import_description = self.data_import_description.to_dict() if self.data_import_description else None

        auto_detect_task_configs: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.auto_detect_task_configs, Unset):
            if self.auto_detect_task_configs is None:
                auto_detect_task_configs = None
            else:
                auto_detect_task_configs = []
                for auto_detect_task_configs_item_data in self.auto_detect_task_configs:
                    auto_detect_task_configs_item = auto_detect_task_configs_item_data.to_dict()

                    auto_detect_task_configs.append(auto_detect_task_configs_item)

        details: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict() if self.details else None

        created_data_points: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.created_data_points, Unset):
            if self.created_data_points is None:
                created_data_points = None
            else:
                created_data_points = self.created_data_points

        state: Union[Unset, str] = UNSET
        if not isinstance(self.state, Unset):
            state = self.state.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "dataSourceId": data_source_id,
            }
        )
        if data_import_description is not UNSET:
            field_dict["dataImportDescription"] = data_import_description
        if auto_detect_task_configs is not UNSET:
            field_dict["autoDetectTaskConfigs"] = auto_detect_task_configs
        if details is not UNSET:
            field_dict["details"] = details
        if created_data_points is not UNSET:
            field_dict["createdDataPoints"] = created_data_points
        if state is not UNSET:
            field_dict["state"] = state

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        data_source_id = d.pop("dataSourceId")

        _data_import_description = d.pop("dataImportDescription", UNSET)
        data_import_description: Union[Unset, None, DataImportDescriptionConfig]
        if _data_import_description is None:
            data_import_description = None
        elif isinstance(_data_import_description, Unset):
            data_import_description = UNSET
        else:
            data_import_description = DataImportDescriptionConfig.from_dict(_data_import_description)

        auto_detect_task_configs = []
        _auto_detect_task_configs = d.pop("autoDetectTaskConfigs", UNSET)
        for auto_detect_task_configs_item_data in _auto_detect_task_configs or []:
            auto_detect_task_configs_item = AutoDetectTaskConfig.from_dict(auto_detect_task_configs_item_data)

            auto_detect_task_configs.append(auto_detect_task_configs_item)

        _details = d.pop("details", UNSET)
        details: Union[Unset, None, DataSourceDetailsDTO]
        if _details is None:
            details = None
        elif isinstance(_details, Unset):
            details = UNSET
        else:
            details = DataSourceDetailsDTO.from_dict(_details)

        created_data_points = cast(List[str], d.pop("createdDataPoints", UNSET))

        _state = d.pop("state", UNSET)
        state: Union[Unset, EnDataSourceState]
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = EnDataSourceState(_state)

        data_source_response = cls(
            data_source_id=data_source_id,
            data_import_description=data_import_description,
            auto_detect_task_configs=auto_detect_task_configs,
            details=details,
            created_data_points=created_data_points,
            state=state,
        )

        return data_source_response



""" Contains all the data models used in inputs/outputs """

from .agent_import_description_config import AgentImportDescriptionConfig
from .agent_import_task_config import AgentImportTaskConfig
from .auto_detect_task_config import AutoDetectTaskConfig
from .create_data_source_request import CreateDataSourceRequest
from .csv_import_task_config import CSVImportTaskConfig
from .data_import_description_config import DataImportDescriptionConfig
from .data_import_request import DataImportRequest
from .data_import_response import DataImportResponse
from .data_import_task_config import DataImportTaskConfig
from .data_source_details_dto import DataSourceDetailsDTO
from .data_source_details_request import DataSourceDetailsRequest
from .data_source_response import DataSourceResponse
from .en_data_source_state import EnDataSourceState
from .file_dto_response import FileDTOResponse
from .file_import_description_config import FileImportDescriptionConfig
from .file_import_task_config import FileImportTaskConfig
from .file_upload_file_multipart_data import FileUploadFileMultipartData
from .gnista_unit_response import GnistaUnitResponse
from .influx_db_import_task_config import InfluxDbImportTaskConfig
from .problem_details import ProblemDetails
from .problem_details_extensions import ProblemDetailsExtensions
from .time_series_mask_import_task_config import TimeSeriesMaskImportTaskConfig
from .update_auto_detect_task_configs_request import UpdateAutoDetectTaskConfigsRequest
from .update_data_import_description_request import UpdateDataImportDescriptionRequest
from .update_data_source_details_request import UpdateDataSourceDetailsRequest
from .update_state_request import UpdateStateRequest



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.data_import_description_config import DataImportDescriptionConfig
from ..models.data_source_details_request import DataSourceDetailsRequest
from ..types import UNSET, Unset

T = TypeVar("T", bound="CreateDataSourceRequest")


@attr.s(auto_attribs=True)
class CreateDataSourceRequest:
    """
    Attributes:
        data_import_description (Union[Unset, None, DataImportDescriptionConfig]):
        details (Union[Unset, None, DataSourceDetailsRequest]):
    """

    data_import_description: Union[Unset, None, DataImportDescriptionConfig] = UNSET
    details: Union[Unset, None, DataSourceDetailsRequest] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        data_import_description: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.data_import_description, Unset):
            data_import_description = self.data_import_description.to_dict() if self.data_import_description else None

        details: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict() if self.details else None

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if data_import_description is not UNSET:
            field_dict["dataImportDescription"] = data_import_description
        if details is not UNSET:
            field_dict["details"] = details

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _data_import_description = d.pop("dataImportDescription", UNSET)
        data_import_description: Union[Unset, None, DataImportDescriptionConfig]
        if _data_import_description is None:
            data_import_description = None
        elif isinstance(_data_import_description, Unset):
            data_import_description = UNSET
        else:
            data_import_description = DataImportDescriptionConfig.from_dict(_data_import_description)

        _details = d.pop("details", UNSET)
        details: Union[Unset, None, DataSourceDetailsRequest]
        if _details is None:
            details = None
        elif isinstance(_details, Unset):
            details = UNSET
        else:
            details = DataSourceDetailsRequest.from_dict(_details)

        create_data_source_request = cls(
            data_import_description=data_import_description,
            details=details,
        )

        return create_data_source_request



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.gnista_unit_response import GnistaUnitResponse
from ..types import UNSET, Unset

T = TypeVar("T", bound="CSVImportTaskConfig")


@attr.s(auto_attribs=True)
class CSVImportTaskConfig:
    """
    Attributes:
        discriminator (str):
        file_id (str):
        name (Union[Unset, None, str]):
        tags (Union[Unset, None, List[str]]):
        date_time_column (Union[Unset, int]):
        value_column (Union[Unset, int]):
        first_row_contains_data (Union[Unset, bool]):
        decimal_seperator (Union[Unset, None, str]):
        column_seperator (Union[Unset, None, str]):
        date_time_format (Union[Unset, None, str]):
        data_point_id (Union[Unset, None, str]):
        unit (Union[Unset, None, str]):
        gnista_unit (Union[Unset, None, GnistaUnitResponse]):
    """

    discriminator: str
    file_id: str
    name: Union[Unset, None, str] = UNSET
    tags: Union[Unset, None, List[str]] = UNSET
    date_time_column: Union[Unset, int] = UNSET
    value_column: Union[Unset, int] = UNSET
    first_row_contains_data: Union[Unset, bool] = UNSET
    decimal_seperator: Union[Unset, None, str] = UNSET
    column_seperator: Union[Unset, None, str] = UNSET
    date_time_format: Union[Unset, None, str] = UNSET
    data_point_id: Union[Unset, None, str] = UNSET
    unit: Union[Unset, None, str] = UNSET
    gnista_unit: Union[Unset, None, GnistaUnitResponse] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        discriminator = self.discriminator
        file_id = self.file_id
        name = self.name
        tags: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            if self.tags is None:
                tags = None
            else:
                tags = self.tags

        date_time_column = self.date_time_column
        value_column = self.value_column
        first_row_contains_data = self.first_row_contains_data
        decimal_seperator = self.decimal_seperator
        column_seperator = self.column_seperator
        date_time_format = self.date_time_format
        data_point_id = self.data_point_id
        unit = self.unit
        gnista_unit: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.gnista_unit, Unset):
            gnista_unit = self.gnista_unit.to_dict() if self.gnista_unit else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "discriminator": discriminator,
                "fileId": file_id,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if tags is not UNSET:
            field_dict["tags"] = tags
        if date_time_column is not UNSET:
            field_dict["dateTimeColumn"] = date_time_column
        if value_column is not UNSET:
            field_dict["valueColumn"] = value_column
        if first_row_contains_data is not UNSET:
            field_dict["firstRowContainsData"] = first_row_contains_data
        if decimal_seperator is not UNSET:
            field_dict["decimalSeperator"] = decimal_seperator
        if column_seperator is not UNSET:
            field_dict["columnSeperator"] = column_seperator
        if date_time_format is not UNSET:
            field_dict["dateTimeFormat"] = date_time_format
        if data_point_id is not UNSET:
            field_dict["dataPointId"] = data_point_id
        if unit is not UNSET:
            field_dict["unit"] = unit
        if gnista_unit is not UNSET:
            field_dict["gnistaUnit"] = gnista_unit

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        discriminator = d.pop("discriminator")

        file_id = d.pop("fileId")

        name = d.pop("name", UNSET)

        tags = cast(List[str], d.pop("tags", UNSET))

        date_time_column = d.pop("dateTimeColumn", UNSET)

        value_column = d.pop("valueColumn", UNSET)

        first_row_contains_data = d.pop("firstRowContainsData", UNSET)

        decimal_seperator = d.pop("decimalSeperator", UNSET)

        column_seperator = d.pop("columnSeperator", UNSET)

        date_time_format = d.pop("dateTimeFormat", UNSET)

        data_point_id = d.pop("dataPointId", UNSET)

        unit = d.pop("unit", UNSET)

        _gnista_unit = d.pop("gnistaUnit", UNSET)
        gnista_unit: Union[Unset, None, GnistaUnitResponse]
        if _gnista_unit is None:
            gnista_unit = None
        elif isinstance(_gnista_unit, Unset):
            gnista_unit = UNSET
        else:
            gnista_unit = GnistaUnitResponse.from_dict(_gnista_unit)

        csv_import_task_config = cls(
            discriminator=discriminator,
            file_id=file_id,
            name=name,
            tags=tags,
            date_time_column=date_time_column,
            value_column=value_column,
            first_row_contains_data=first_row_contains_data,
            decimal_seperator=decimal_seperator,
            column_seperator=column_seperator,
            date_time_format=date_time_format,
            data_point_id=data_point_id,
            unit=unit,
            gnista_unit=gnista_unit,
        )

        csv_import_task_config.additional_properties = d
        return csv_import_task_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="DataSourceDetailsDTO")


@attr.s(auto_attribs=True)
class DataSourceDetailsDTO:
    """
    Attributes:
        name (Union[Unset, None, str]):
        description (Union[Unset, None, str]):
        created_at (Union[Unset, datetime.datetime]):
        created_by (Union[Unset, None, str]):
    """

    name: Union[Unset, None, str] = UNSET
    description: Union[Unset, None, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    created_by: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        description = self.description
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        created_by = self.created_by

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if created_by is not UNSET:
            field_dict["createdBy"] = created_by

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        created_by = d.pop("createdBy", UNSET)

        data_source_details_dto = cls(
            name=name,
            description=description,
            created_at=created_at,
            created_by=created_by,
        )

        return data_source_details_dto



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="FileImportDescriptionConfig")


@attr.s(auto_attribs=True)
class FileImportDescriptionConfig:
    """
    Attributes:
        discriminator (str):
        file_id (str):
        column_seperator (Union[Unset, None, str]):
        decimal_seperator (Union[Unset, None, str]):
        date_time_format (Union[Unset, None, str]):
        first_row_contains_data (Union[Unset, bool]):
    """

    discriminator: str
    file_id: str
    column_seperator: Union[Unset, None, str] = UNSET
    decimal_seperator: Union[Unset, None, str] = UNSET
    date_time_format: Union[Unset, None, str] = UNSET
    first_row_contains_data: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        discriminator = self.discriminator
        file_id = self.file_id
        column_seperator = self.column_seperator
        decimal_seperator = self.decimal_seperator
        date_time_format = self.date_time_format
        first_row_contains_data = self.first_row_contains_data

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "discriminator": discriminator,
                "fileId": file_id,
            }
        )
        if column_seperator is not UNSET:
            field_dict["columnSeperator"] = column_seperator
        if decimal_seperator is not UNSET:
            field_dict["decimalSeperator"] = decimal_seperator
        if date_time_format is not UNSET:
            field_dict["dateTimeFormat"] = date_time_format
        if first_row_contains_data is not UNSET:
            field_dict["firstRowContainsData"] = first_row_contains_data

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        discriminator = d.pop("discriminator")

        file_id = d.pop("fileId")

        column_seperator = d.pop("columnSeperator", UNSET)

        decimal_seperator = d.pop("decimalSeperator", UNSET)

        date_time_format = d.pop("dateTimeFormat", UNSET)

        first_row_contains_data = d.pop("firstRowContainsData", UNSET)

        file_import_description_config = cls(
            discriminator=discriminator,
            file_id=file_id,
            column_seperator=column_seperator,
            decimal_seperator=decimal_seperator,
            date_time_format=date_time_format,
            first_row_contains_data=first_row_contains_data,
        )

        file_import_description_config.additional_properties = d
        return file_import_description_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
